import React from 'react';
/**
 * Popup informs users about critical information or require decisions.
 */
export declare type PopupProps = {
    /**
     * Popup max width
     */
    maxWidth?: string;
    /**
     * Popup image
     */
    image?: any;
    /**
     * Popup title
     */
    title?: string;
    /**
     * Popup className (can be used to add more styles to mainIcon by targeting `main-icon` class in case of using a custom string)
     */
    className?: string;
    /**
     * Popup content
     */
    children?: any;
    /**
     * Popup button label
     */
    btnLabel1?: string | React.ReactNode;
    btnLabel2?: string | React.ReactNode;
    btnLabel3?: string | React.ReactNode;
    /**
     * Whether this Popup is open or not
     */
    open?: boolean;
    /**
     * Applies to mobile view only, Button Group Position
     */
    isMobileVertical?: boolean;
    /**
     * Applies to mobile view only, Close button to the left of the header
     * With ISO always displayed on the left
     */
    isCloseButtonLeft?: boolean;
    /**
     * Callback when close icon is clicked. Normally, it is used to update `open` prop to close the popup.
     */
    onClose?: React.MouseEventHandler;
    /**
     * Callback when popup main button is clicked
     */
    onButtonClick1?: React.MouseEventHandler;
    onButtonClick2?: React.MouseEventHandler;
    onButtonClick3?: React.MouseEventHandler;
};
export declare const Popup: ({ maxWidth, image, title, className, children, btnLabel1, btnLabel2, btnLabel3, open, isMobileVertical, isCloseButtonLeft, onClose, onButtonClick1, onButtonClick2, onButtonClick3, ...props }: PopupProps) => JSX.Element;
