import React, { forwardRef } from "react";
import { IconProps, IconName } from "./types";
import icons from "./icons";
import { getIconStyles } from "./styles";

export const Icon = forwardRef(
  (
    {
      name,
      size = "unset",
      fill = "fill-current",
      className,
      ...rest
    }: IconProps,
    ref: React.Ref<SVGSVGElement>
  ) => {
    const { html, info } = icons[name];
    const { viewBox } = info;
    const { width, height } = info;
    const finalClass = `${getIconStyles({ fill, size })} ${className}`;

    return (
      <svg
        ref={ref}
        className={finalClass}
        dangerouslySetInnerHTML={{ __html: html }}
        height={size === "unset" ? height : undefined}
        viewBox={viewBox}
        width={size === "unset" ? width : undefined}
        {...rest}
      />
    );
  }
);

export type { IconName };
