import React from 'react';

import ButtonStyle from './styles';

const STYLES = [
  'btn-pri-hi',
  'btn-sec-hi',
  'btn-net-hi',
  'btn-pri-med',
  'btn-sec-med',
  'btn-net-med',
  'btn-pri-low',
  'btn-sec-low',
  'btn-net-low',
  'hyperlink'
]

export type ButtonProps = {
  id?: string,
  disabled?: boolean,
  children?: React.ReactNode,
  className?: string,
  styles?: 'btn-pri-hi' |
    'btn-sec-hi' |
    'btn-net-hi' |
    'btn-pri-med' |
    'btn-sec-med' |
    'btn-net-med' |
    'btn-pri-low' |
    'btn-sec-low' |
    'btn-net-low' |
    'hyperlink',
} & React.HTMLAttributes<HTMLButtonElement>;

export const Button = React.forwardRef(
  (
    {
      id,
      disabled = false,
      styles,
      children,
      className,
      ...props
   }: ButtonProps,
    ref: React.Ref<HTMLButtonElement>
  ) => {
    const [color, setColor] = React.useState('pri');
    const [type, setType] = React.useState('hi');

    const classname = styles || className?.split(' ').reverse().find(value => STYLES.includes(value));

    React.useEffect(() => {
      if (classname) {
        if (classname !== 'hyperlink') {
          setColor(classname.split('-')?.[1]);
          setType(classname.split('-')?.[2]);
        } else {
          setColor('hyperlink');
        }
      }
    }, [classname]);

    const attrs = {
      ref,
      ...props,
    };

    return (
      <ButtonStyle
        {...attrs}
        className={`btn ${color} ${type} ${disabled && 'disabled'} ${className} ${styles}`}
      >
        {children}
      </ButtonStyle>
    );
});
