import React from 'react';
import { isIOS } from 'react-device-detect';

import theme from '../../theme';

import {
  CheckboxContainer,
  ContextWrapper,
  StyledCheckbox,
  Label,
  Description,
} from './styles';

const { colors } = theme;

export type CheckboxProps = {
  id?: string,
  label?: string,
  description?: string,
  type?: 'checkbox' | 'radio' | 'switch',
  className?: string,
  name?: string,
  checked?: boolean,
  color?: string,
  disabled?: boolean,
} & React.HTMLAttributes<HTMLInputElement>;

export const Checkbox = (
  {
    label,
    description,
    className,
    type= 'checkbox',
    checked = false,
    color = 'secondary',
    disabled = false,
    ...props
  }: CheckboxProps) => {
  const inputAttrs = {
    type: type === 'switch' ? 'checkbox' : type,
    disabled,
    ...props,
  };

  const colorCheckbox = colors?.[color] || color || colors.secondary;

  const disabledClass = disabled ? 'disabled' : '';
  const isIOSClass = isIOS ? 'isIOS' : '';
  const checkboxClasses = `${className} ${disabledClass}`;

  return (
    <CheckboxContainer>
      {(label || description) && (
        <ContextWrapper className={type}>
          {label && <Label className={disabledClass}>{label}</Label>}
          {description && <Description className={disabledClass}>{description}</Description>}
        </ContextWrapper>
      )}
      <StyledCheckbox className={checkboxClasses} colorCheckbox={colorCheckbox}>
        <input
          {...inputAttrs}
          checked={checked}
        />
        <span className={`${type} ${isIOSClass}`}/>
      </StyledCheckbox>
    </CheckboxContainer>
  );
};
