import styled from 'styled-components';
import theme from '../../theme';

const { colors } = theme;

const CheckboxContainer = styled.div`
  display: flex;
`;

const ContextWrapper = styled.div`
  display: flex;
  flex-direction: column;
  margin-right: 1.7rem;
  font-weight: 700;
  font-size: 14px;
  line-height: 1.25rem;
  color: ${colors.text};
  width: 17.5rem;

  &.switch {
    width: 16.8rem;
  }
`;

const Label = styled.span`
  overflow: hidden;
  text-overflow: ellipsis;

  &.disabled {
    opacity: 0.38;
  }
`;

const Description = styled.span`
  font-weight: 400;
  font-size: 12px;
  line-height: 1rem;
  margin-top: 4px;

  &.disabled {
    opacity: 0.38;
  }
`;

/**
 *  @type {React.FC<any>}
 */
const StyledCheckbox = styled.label<{colorCheckbox: string;}>`
  position: relative;
  cursor: pointer;
  height: max-content;

  & > input {
    visibility: hidden;
    width: 0;
    height: 0;
  }

  & > span {
    color: ${colors.gray500};
    position: relative;
    display: inline-block;
    border: 2px solid;
    height: 20px;
    width: 20px;
  }

  & > .checkbox {
    border-radius: 4px;
    height: 18px;
    width: 18px;
    &.isIOS{
      height: 22px;
      width: 22px;
      border-radius: 8px;
    }
  }

  & > .radio {
    border-radius: 100%;
    &.isIOS {
      height: 22px;
      width: 22px;
    }
  }

  & > .switch {
    width: 34px;
    height: 14px;
    border-radius: 7px;
    background: rgba(0, 0, 0, 0.2);
    color: transparent;

    :after {
      content: '';
      position: absolute;
      left: -2px;
      top: -5px;
      width: 20px;
      height: 20px;
      border-radius: 100%;
      z-index: 0;
      transition-duration: 150ms;
      background: ${colors.white};
      box-shadow: 0 1px 1px rgba(0, 0, 0, 0.14), 0 2px 1px rgba(0, 0, 0, 0.12), 0 1px 3px rgba(0, 0, 0, 0.2);
    }

    &.isIOS {
      width: 51px;
      height: 31px;
      border-radius: 25px;
      background: rgba(120, 120, 128, 0.16);

      &:after {
        left: 0;
        top: 0;
        width: 27px;
        height: 27px;
        box-shadow: none;
      }
    }
  }

  input:checked {
    + .checkbox {
      color: ${({colorCheckbox}) => colorCheckbox};
      background: ${({colorCheckbox}) => colorCheckbox};

      &:after {
        content: '';
        position: absolute;
        left: 4px;
        top: 0;
        width: 7px;
        height: 12px;
        border: solid ${colors.white};
        border-width: 0 2px 2px 0;
        transform: rotate(45deg);
      }

      &.isIOS:after {
        left: 6px;
        top: 2px;
        width: 6px;
        height: 11px;
        border-width: 0 2px 2px 0;
      }
    }

    + .radio {
      background: ${colors.white};
      color: ${({colorCheckbox}) => colorCheckbox};

      &:after {
        content: '';
        position: absolute;
        background-color: ${({colorCheckbox}) => colorCheckbox};
        border-radius: 100%;
        left: 3px;
        top: 3px;
        width: 10px;
        height: 10px;
      }

      &.isIOS:after {
        left: 1px;
        top: 1px;
        width: 16px;
        height: 16px;
      }
    }

    + .switch {
      background: ${({colorCheckbox}) => `${colorCheckbox}61`};

      &:after {
        transform: translateX(14px);
        background: ${({colorCheckbox}) => colorCheckbox};
        box-shadow: 0 3px 8px rgba(0, 0, 0, 0.15), 0 3px 1px rgba(0, 0, 0, 0.06);
      }

      &.isIOS {
        background: ${({colorCheckbox}) => colorCheckbox === colors.secondary ? colors.backgroundIOS : colorCheckbox};

        :after {
          transform: translateX(20px);
          background: ${colors.white};
        }
      }
    }
  }

  &.disabled {
    opacity: 0.38;
    cursor: auto;
  }
`;
export {
  CheckboxContainer,
  ContextWrapper,
  StyledCheckbox,
  Label,
  Description,
};
