import React from 'react';
import theme from '../../theme';
import { noop } from '../../utils';

import {
  ChipStyle,
  LableChip,
} from './styles';
import { Icon, IconName } from "../../Icon";

const { colors } = theme;

export type ChipProps = {
  /**
   * Chip id
   */
  id?: string,
  /**
   * Chip label
   */
  label?: string,
  /**
   * Chip className
   */
  className?: string,
  /**
   * Chip name
   */
  name?: string,
  /**
   * Chip value
   */
  value: boolean,
  /**
   * Change radio buttons active state color
   */
  color?: string,
  /**
   * Whether this chip is disabled initially or not
   */
  disabled?: boolean,
  /**
   * Change event
   */
  onChange?: (value: boolean) => void,
  prefixIcon?: IconName | React.ReactNode,
  suffixIcon?: IconName | React.ReactNode,
} & React.HTMLAttributes<HTMLButtonElement>;

export const Chip = (
  {
    label = '',
    value = false,
    color = 'primary',
    disabled = false,
    onChange = noop,
    className,
    prefixIcon,
    suffixIcon,
    ...props
  }: ChipProps) => {
  const attrs = {
    disabled,
    ...props,
  };

  const colorChip = colors?.[color] || color || colors.primary;
  const disabledClass = disabled ? 'disabled' : '';
  const isActiveClass = value ? 'isActive' : '';
  const chipClasses = `${className} ${disabledClass} ${isActiveClass}`;

  const handleClick = () => {
    return onChange(!value);
  };

  return (
    <ChipStyle
      {...attrs}
      color={colorChip}
      className={chipClasses}
      onClick={handleClick}
    >
      {prefixIcon && (
        <span className="prefixIcon">
          {typeof prefixIcon === "string"  ? (
            <span className="prefixIcon">
              <Icon name={prefixIcon} />
            </span>
          ) : prefixIcon}
        </span>
      )}
      <LableChip>{label}</LableChip>
      {suffixIcon && (
        <span className="prefixIcon">
          {typeof suffixIcon === "string"  ? (
            <span className="suffixIcon">
              <Icon name={suffixIcon} />
            </span>
          ) : suffixIcon}
        </span>
      )}
    </ChipStyle>
  );
};

