import styled from 'styled-components';
import theme from '../../theme';

const {
  colors,
  radii,
  sizes,
  zIndices,
  fonts,
} = theme;

const Modal = styled.div`
  display: grid;
  place-items: center;
  position: fixed;
  top: 0;
  left: 0;
  width: ${sizes.vW};
  height: ${sizes.vH};
  padding: 0.75rem;
  z-index: ${zIndices.modal};
  font-family: ${fonts.body};
`;

const Backdrop = styled.div`
  background-color: ${colors.black};
  position: absolute;
  top: 0;
  left: 0;
  width: ${sizes.full};
  height: ${sizes.full};
  opacity: 0.3;
`;

const StyledDialog = styled.div`
  width: 100%;
  max-width: 21.5rem;
  overflow-x: hidden;
  overflow-y: auto;
  box-shadow: 0 12px 36px rgba(0, 0, 0, 0.25);
  z-index: ${zIndices.up};
  background-color: ${colors.white};
  border-radius: ${radii.sm};
  max-height: 35rem;

  &.isLargeSize {
    max-width: 35rem;
  }

  &.isIOS {
    background-color: ${colors.grayIOS};
    backdrop-filter: blur(22px);
    border-radius: 14px;
  }
`;

const ContextWrapper = styled.div`
  position: relative;
  width: ${sizes.full};
  padding: 1.5rem 2rem;

  .title {
    font-weight: 600;
    font-size: 1.25rem;
    line-height: 1.75rem;
    color: ${colors.text};
    margin-bottom: 1rem;
  }

  &.isMobile {
    padding: 1.5rem 1rem;
    .title {
      font-size: 1rem;
      font-weight: 700;
      line-height: 1.38rem;
    }

    &.isIOS {
      padding: 1rem 1rem 0;
      .title {
        color: ${colors.black};
        font-size: 17px;
        font-weight: 600;
        line-height: 1.38rem;
        letter-spacing: -0.41px;
        text-align: center;
        margin-bottom: 2px;
      }
    }
  }

  &.hasImage {
    padding-top: 1rem;
  }
`;

const Image = styled.img`
  width: 100%;
  object-fit: cover;
`;

const ChildrenWrapper = styled.div`
  max-height: calc(${sizes.vH} - 280px);
  overflow-y: hidden;
  color: ${colors.text060};
  font-weight: 400;
  font-size: 14px;
  line-height: 22px;
  margin-bottom: 1rem;

  &.no-button {
    max-height: calc(${sizes.vH} - 224px);
    margin-bottom: 0;
  }

  &.is-single-string {
    white-space: pre-wrap;
  }

  &.isIOS {
    font-size: 13px;
    line-height: 18px;
    text-align: center;
    letter-spacing: -0.078px;
  }
`;

const ButtonWrapper = styled.div`
  display: flex;
  flex-direction: row-reverse;

  button{
    margin-top: 0.75rem;
    margin-left: 8px;
    text-transform: uppercase;
  }

  .buttonAction2, .buttonAction3 {
    color: ${colors.text};
  }

  &.isMobileVertical {
    flex-wrap: wrap;
    align-items: flex-end;
    flex-direction: column;
  }

  &.isIOS {
    margin: 0 -1rem;
    border-top: 0.5px solid rgba(60, 60, 67, 0.36);
    button {
      flex: 1;
      justify-content: center;
      margin-top: 0;
      padding: 12px 0;
      width: 100%;
      margin-left: 0;
      border-radius: 0;
      background: transparent;
      text-transform: capitalize;
      color: ${colors.secondary};

      &.buttonAction2, &.buttonAction3 {
        font-weight: 400;
      }
    }
    &.isMobileVertical {
      align-items: center;
    }
  }
`;

const Separator = styled.span`
  width: 0.5px;
  height: auto;
  background: rgba(60, 60, 67, 0.36);

  &.isIOS.isMobileVertical {
    width: 100%;
    height: 0.5px;
  }
`;

export { Modal, Backdrop, StyledDialog, ContextWrapper, Image, ChildrenWrapper, ButtonWrapper, Separator };
