import React from 'react';
import { DropdownSingle } from './DropdownSingle';
import { DropdownMulti } from './DropdownMulti';
import { noop } from '../../utils';

export interface DropdownOption { value: string, label: string };

export type DropdownProps = {
  /**
   * Custom class to override dropdown's style.
   */
  className?: string,
  /**
   * Index name
   */
  name?: string,
  /**
   * Index label
   */
  label?: string,
  /**
   * Index ref (implement with useRef() hooks)
   */
  inputRef?: any,
  /**
   * The Index content value
   */
  value?: string | string[],
  /**
   * Callback when user click / tap on the input
   */
  onClick?: (value: string | number) => void,
  /**
   * Callback when user input
   */
  onChange?: (value: string | number) => void,
  /**
   * Callback when user blur
   */
  onBlur?: () => void,
  /**
   * Callback when user focus
   */
  onFocus?: () => void,
  displayFn?: (item: DropdownOption | any) => void | string,
  /**
   * Disabled dropdown
   */
  disabled?: boolean,
  /**
   * Whether this input is required or not
   */
  required?: boolean,
  /**
   * The id of dropdown.
   */
  id?: string,
  /**
   * Index status (usefull when implemented with form validation)
   */
  status?: 'error' | 'default',
  /**
   * Index options. Options is an array and each array item is an object with shape of `{value: string, label: string}`.
   */
  options?: DropdownOption[],
  multiSelect?: boolean,
  type?: 'short' | 'tall' | 'scroll',
  size?: 'medium' | 'small'
  placeholder?: string,
  assitiveText?: string,
} & React.HTMLAttributes<HTMLInputElement>;

export const Dropdown = (
  {
    label = '',
    inputRef = null,
    value,
    onClick = noop,
    onChange = noop,
    onBlur = noop,
    onFocus = noop,
    displayFn = (item)  => item?.label,
    disabled = false,
    required = false,
    status = 'default',
    options = [],
    multiSelect = false,
    type = 'short',
    size = 'medium',
    assitiveText = '',
    ...props
  }: DropdownProps) => {
  /**
   * @type {{[key: string]: any }}
   */
  const attrs = {
    label,
    value,
    onClick,
    onChange,
    onBlur,
    onFocus,
    displayFn,
    disabled,
    required,
    status,
    inputRef,
    options,
    type,
    size,
    assitiveText,
    readOnly: true,
    ...props,
  };


  return ( multiSelect ? <DropdownMulti {...attrs} /> : <DropdownSingle {...attrs} />);
};
