import styled from 'styled-components';
import theme from '../../theme';

const {
  colors,
  fonts,
} = theme;

const Container = styled.div`
  position: relative;
`;

const DropdownWrapper = styled.div`
  width: 100%;

  .icon > svg {
    color: ${colors.gray700};
    font-size: 10px;
  }

  &.isOpen .icon > svg {
    transform: rotateX(180deg);
  }
`;

const ListBox = styled.div<{ minWidth: number }>`
  position: absolute;
  display: flex;
  flex-direction: column;
  background-color: ${colors.white};
  pointer-events: auto;
  visibility: visible;
  margin-top: -4px;
  border: 1px solid rgba(0, 0, 0, 0.08);
  box-shadow: 0 8px 8px rgba(0, 0, 0, 0.15);
  width: fit-content;
  min-width: ${({minWidth}) => `${minWidth}px`};
  z-index: 999;
  font-family: ${fonts.body};

  &.multiSelect {
    padding: 0 0 3.25rem;
    &.isMobileIOS {
      padding: 0 0 5.4rem;
    }
  }

  &.hidden {
    padding: 0;
    pointer-events: none;
    visibility: hidden;
    height: 0;
  }

  &.assitiveText {
    margin-top: -1.5rem;
  }

  &.isMobile {
    position: fixed;
    width: 100%;
    height: 100%;
    top: 0;
    left: 0;

    &.isMobileIOS {
      height: auto;
      max-height:94%;
      top: auto;
      bottom: 0;
      border-radius: 10px 10px 0 0;
    }
  }
`;

const ListBoxMobileHeader = styled.div`
  font-size: 1.35rem;
  line-height: 1.63rem;
  padding: 1.1rem;
  color: ${colors.gray500};
  box-shadow: 0 1px 2px rgba(0, 0, 0, 0.3), 0 2px 6px 2px rgba(0, 0, 0, 0.15);
  margin-bottom: 0.5rem;
  background-color: ${colors.white};
  z-index: 999;

  &.isMobileIOS {
    box-shadow: none;
    display: flex;
    justify-content: center;
    padding: 0.7rem 4rem;
    align-items: center;
    margin-bottom: 0;
    border-radius: 10px 10px 0 0;
  }
`;

const LabelTitle = styled.span`
  &.isMobileIOS {
    font-size: 1.1rem;
    color: ${colors.black};
  }
`;

const ButtonReset = styled.button`
  padding: 1rem 0.5rem;
  background-color: transparent;
  color: ${colors.secondary};
  outline: none;
  line-height: 1.5rem;
  font-size: 1.07rem;
  position: absolute;
  right: 0;
`;

const ArrowBackButton = styled.button`
  outline: none;
  border: none;
  background-color: transparent;
  padding-right: 1.25rem;
  svg {
    font-size: 1rem;
    color: ${colors.gray500};
  }
`;

const ListBoxListContainer = styled.div<{ heightType: string }>`
  display: flex;
  flex-direction: column;
  width: 100%;
  border: 1px solid #00000014;
  overflow-y: auto;
  z-index: 9;
  overflow-x: hidden;
  background-color: ${colors.white};

  max-height: ${({heightType}) => {
    let maxHeight = '15.5rem';
    if (heightType !== 'short') {
      maxHeight = heightType === 'tall' ? '30.5rem' : '31.8rem';
    }
    return maxHeight;
  }};

  &.isMobile {
    max-height: 100%;
    border: 0;
  }
`;

const ListItem = styled.div`
  position: relative;
  display: flex;
  align-items: center;
  font-size: 1rem;
  line-height: 1.5rem;
  color: ${colors.gray700};
  padding: 0.75rem 1.1rem 0.75rem 0.75rem ;
  justify-content: space-between;
  cursor: pointer;
  min-width: 100%;
  max-width: 30vw;

  span {
    white-space: nowrap;
    overflow: hidden;
    text-overflow: ellipsis;
  }

  &:hover, &.selectedItem, &:hover.multiSelect {
    background-color: ${colors.secondary400};
    color: ${colors.white};
  }

  &.multiSelect {
    justify-content: start;
    &.isMobileIOS {
      justify-content: space-between;
    }
  }

  &.multiSelect.selectedItem {
    background-color: transparent;
    color: ${colors.gray700};
    &.isMobile {
      color: ${colors.secondary};
    }
  }
  &:hover.multiSelect {
    background-color: ${colors.secondary400};
    color: ${colors.white};
    &.selectedItem {
      color: ${colors.secondary};
    }
    &.isMobile {
      color: ${colors.gray700};
      background-color: transparent;
      &.selectedItem {
        color: ${colors.secondary};
      }
    }
  }

  &:hover.isMobile {
    color: ${colors.gray700};
  }

  &.isMobileIOS {
    font-size: 1.065rem;
    line-height: 1.3rem;

    &:hover, &.selectedItem {
      color: ${colors.secondary};
      background-color: transparent;
    }
  }
`;

const LineBottom = styled.span`
  height: 0.5px;
  bottom: 0;
  position: absolute;
  width: 100%;
  background-color: ${colors.gray400};

`;

const IconWrapper = styled.div`
  display: flex;
  align-items: center;
  width: 1.1rem;
  margin-left: 1.1rem;

  svg {
    width: 1rem;
    height: 1rem;
    color: ${colors.white};
  }

  &.selectedItem.isMobileIOS > svg {
    color: ${colors.secondary};
  }
`;

const CheckboxWrapper = styled.span`
  padding-right: 1.1rem;
  min-width: 40px;
  pointer-events: none;
`;

const ButtonFooter = styled.div`
  display: flex;
  justify-content: end;
  align-items: center;
  position: absolute;
  bottom: 0;
  height: 3.25rem;
  background-color: ${colors.white};
  width: 100%;

  &.isMobileIOS {
    padding: 1rem 0.5rem;
    height: 5.4rem;
  }
`;

const ItemButton = styled.button`
  font-weight: bold;
  padding: 8px 12px;
  background-color: transparent;
  color: ${colors.text};
  outline: none;
  font-size: 14px;
  line-height: 20px;

  &.apply-button {
    background-color: ${colors.gray100};
    font-weight: normal;
    width: 100%;
    font-size: 1.25rem;
    line-height: 1.5rem;
    padding: 1rem;
    border-radius: 13px;
    color: ${colors.secondary};
  }
`;

const LineButton = styled.div`
  width: 1.25rem;
  border: 1px solid ${colors.text038};
  transform: rotate(90deg);
`;

const BackgroundListBox = styled.div`
  top: 0;
  left: 0;
  width: 100%;
  height: 100%;
  position: fixed;
  background-color: rgba(0, 0, 0, 0.3);
`;

export {
  Container,
  DropdownWrapper,
  ListBox,
  LineBottom,
  ListBoxMobileHeader,
  LabelTitle,
  ButtonReset,
  ArrowBackButton,
  ListBoxListContainer,
  ListItem,
  IconWrapper,
  CheckboxWrapper,
  ButtonFooter,
  ItemButton,
  LineButton,
  BackgroundListBox,
};
