import React from 'react';
import { isMobile, isIOS } from 'react-device-detect';

import { Button, cx, Icon, IconName, noop } from '../../index';
import {
  InfoboxContainer,
  InfoWrapper,
  IconWrapper,
  ContextWrapper,
} from './styles';

export type InfoboxProps = {
  /**
   * Infobox id
   */
  id?: string,
  /**
   * Infobox title
   */
  title?: string,
  /**
   * Infobox description
   */
  description?: string,
  /**
   * Infobox className
   */
  className?: string,
  /**
   * Change radio buttons active state color
   */
  color?: 'green' | 'red' | 'neutral',
  /**
   * Infobox button display or not
   */
  isButton?: boolean,
  /**
   * Infobox marked to display border or not
   */
  isHighEmphasis?: boolean,
  /**
   * Infobox button label
   */
  buttonLabel?: string,
  /**
   * Click event
   */
  onClick?: React.MouseEventHandler,
  /**
   * Infobox icon
   */
  icon?: IconName | React.ReactNode,
} & React.HTMLAttributes<HTMLDivElement>;

export const Infobox = (
  {
    id,
    title,
    description,
    color = 'green',
    className,
    isHighEmphasis,
    isButton,
    buttonLabel = 'cta',
    onClick = noop,
    icon,
    ...props
  }: InfoboxProps) => {

  const attrs = {
    id,
    ...props,
  };
  const infoBoxClasses = cx(className, color, isMobile && 'isMobile', isHighEmphasis && 'isHighEmphasis');

  const handleClick = (e) => {
    onClick(e);
  };

  return (
    <InfoboxContainer {...attrs} className={infoBoxClasses}>
      {icon && (
        <IconWrapper className={cx(color)}>
          { typeof icon === "string" ? (
            <Icon name={icon} />
          ) : icon}
        </IconWrapper>
      )}
      <InfoWrapper className={cx(isMobile && 'isMobile')}>
        <ContextWrapper>
          <span className={cx('title', isIOS && 'isIOS')}>{title}</span>
          <span className={cx('description', isIOS && 'isIOS')}>{description}</span>
        </ContextWrapper>
        {isButton && (
          <Button color={color === 'green' ? 'secondary' : 'primary'} onClick={handleClick}>
            {buttonLabel}
          </Button>
        )}
      </InfoWrapper>
    </InfoboxContainer>
  );
};
