import styled from 'styled-components';
import theme from '../../theme';

const {
  colors,
  sizes,
  fonts,
  radii,
  fontWeights,
  texts,
  inputHeights,
} = theme;

const InputContainer = styled.div`
  position: relative;
  width: ${sizes.full};
`;

const Container = styled.div<{ containerWidth:string }>`
  width: ${({ containerWidth }) => containerWidth};
  position: relative;
  font-family: ${fonts.body};
`;

const SubLabel = styled.label<{ prefixWidth: number }>`
  position: absolute;
  left: 0;
  cursor: text;
  pointer-events: none;
  transform-origin: top left;
  transition: transform 0.1s ease;
  color: ${colors.textLighter};
  font-size: 1rem;

  &.required::after {
    content: '*';
    margin-left: 4px;
  }

  &.focus {
    background-color: ${colors.white};
    color: ${colors.secondary};
    padding: 0 4px;
  }

  &.focus, &.hasValue {
    transform: translate(${({prefixWidth}) => prefixWidth ? (-16 - prefixWidth) : -8}px, -26px);
    background-color: ${colors.white};
    padding: 0 4px;
    font-size: 0.75rem;
  }
  &.focus.small,
  &.hasValue.small {
    transform: translate(${({prefixWidth}) => prefixWidth ? (-16 - prefixWidth) : -8}px, -16px);
  }

  &.error {
    color: ${colors.primary900};
  }
`;

const InputStyle = styled.input`
  width: ${sizes.full};
  height: ${sizes.full};
  font-size: 1rem;
  color: ${colors.text};
  appearance: none;
  outline: none;
  border: none;
  background-color: ${colors.white};

  &:disabled {
    background-color: ${colors.gray100};
    cursor: default;
  }
  
  padding: 0;
  text-overflow: ellipsis;
  caret-color: ${colors.secondary};

  &[disabled] {
    color: rgba(0, 0, 0, 0.6);
  }
`;

const TextareaStyle = styled.textarea`
  height: 100%;
  resize: none;
  padding: 0;
  caret-color: ${colors.secondary};

  &[disabled] {
    color: rgba(0, 0, 0, 0.6);
  }
`;

const ParagraphWrapper = styled.div`
  display: flex;
  justify-content: space-between;
  color: ${colors.textLighter};
  font-size: 0.75rem;
  margin-left: 4px;
  line-height: 1.5;
  margin-top: 4px;
  margin-bottom: 0;

  &.error .assitiveText {
    color: ${colors.primary900};
  }

  &.isCharacterLimitError .characterLimit {
    color: ${colors.primary900};
  }
`;

const InputWrapper = styled.div`
  display: flex;
  flex-direction: row;
  width: ${sizes.full};
  height:  ${inputHeights.md};
  position: relative;
  border-radius: ${radii.sm};
  border: 1px solid ${colors.border};
  background-color: #ffffff;
  padding: 1rem 0.75rem;
  font-family: ${fonts.body};
  margin-top: 4px;

  &.small {
    height: ${inputHeights.sm};
    padding: 6px 12px;
  }

  &.longParagraph {
    height: ${inputHeights.xs};
  }

  &.longParagraph.disabled.noValue {
    height: 148px;
  }

  &:focus-within {
    border-color: ${colors.secondary};
  }

  &.error {
    border-color: ${colors.primary900};
  }

  &.disabled {
    background-color: ${colors.gray100};
    border: 1px solid rgba(0, 0, 0, 0.08);
  }

  & > button {
    background: transparent;
    outline: none;
    border: none;
    height: 32px;
    min-width: 10rem;
    position: absolute;
    top: 0;
    right: 2px;
    color: ${colors.link};
    padding: 8px;
  }

  & > .password {
    top: -1px;
  }

  & svg {
    font-size: 0.75rem;
  }
`;

const SuffixWrapper = styled.div<{ longParagraph }>`
  display: flex;
  align-items: ${({longParagraph}) => longParagraph ? 'start' : 'center'};
  & svg {
    font-size: 1.25rem;
  }
`;

const ErrorIcon = styled.span`
  color: ${colors.primary900};
  margin-left: 14px;
  align-items: center;
  display: flex;
  & svg {
    font-size: 1.25rem;
  }
`;

const IconWrapper = styled.div`
  margin-left: 14px;
  display: flex;
  align-items: center;
  
  &.dropdown svg {
    color: ${colors.gray700};
    font-size: 10px;
  }
  &.disabled.dropdown svg {
    color: ${texts.text038};
  }

  &.dropdown.focus > svg {
    transform: rotateY(180);
  }
`;

const PrefixLabel = styled.div`
  margin-right: 8px;
  font-size: 16px;
  color: ${texts.text038};
  text-transform: uppercase;
  font-weight: ${fontWeights.bold};
`;

const SuffixLabel = styled.div`
  margin-left: 14px;
  font-size: 16px;
  color: ${texts.text038};
  text-transform: uppercase;
  font-weight: ${fontWeights.bold};
`;

export {
  InputWrapper,
  ParagraphWrapper,
  Container,
  ErrorIcon,
  SuffixLabel,
  PrefixLabel,
  InputContainer,
  SubLabel,
  InputStyle,
  TextareaStyle,
  SuffixWrapper,
  IconWrapper,
};
