import styled from 'styled-components';
import theme from '../../theme';

const {
  colors,
  radii,
  sizes,
  zIndices,
  fonts,
} = theme;

const Modal = styled.div`
  display: grid;
  place-items: center;
  position: fixed;
  top: 0;
  left: 0;
  width: ${sizes.vW};
  height: ${sizes.vH};
  padding: 0.75rem;
  z-index: ${zIndices.modal};
  font-family: ${fonts.body};

  &.isMobile {
    padding: 0;
  }
`;

const Backdrop = styled.div`
  background-color: ${colors.black};
  position: absolute;
  top: 0;
  left: 0;
  width: ${sizes.full};
  height: ${sizes.full};
  opacity: 0.3;
`;

const StyledPopup = styled.div<{ maxWidth?: string }>`
  width: fit-content;
  overflow-x: hidden;
  overflow-y: auto;
  box-shadow: 0 12px 36px rgba(0, 0, 0, 0.25);
  z-index: ${zIndices.up};
  background-color: ${colors.white};
  border-radius: ${radii.sm};
  max-height: 35rem;
  ${({maxWidth}) => maxWidth ? `max-width:${maxWidth};` : ''}

  &.isMobile {
    width: 100%;
    height: 100%;
    max-height: 100%;
    border-radius: 0;
  }
`;

const StyledHeader = styled.div`
  display: flex;
  align-items: center;
  padding: 1.5rem 1rem 1rem 2rem;
  justify-content: space-between;
  background-color: ${colors.white};

  &.isSticky {
    top: 0;
    position: sticky;
    z-index: ${zIndices.up};
    box-shadow: 0 4px 6px rgba(0, 0, 0, 0.15);
  }


  .title {
    font-weight: 600;
    font-size: 1.25rem;
    line-height: 1.75rem;
    color: ${colors.black};
  }

  .closeButton {
    padding: 0;
    width: 1.5rem;
    height: 1.5rem;
    display: flex;
    align-items: center;
    justify-content: center;
    background: transparent;
    margin-left: 1rem;

    &:focus {
      outline: none;
    }
    svg {
      font-size: 14px;
    }
  }

  &.isCloseButtonLeft.isMobile,
  &.isIOS {
    justify-content: flex-end;
    flex-flow: row-reverse;
    .closeButton {
      margin-left: 0;
      margin-right: 1rem;
    }
  }

  &.isMobile {
    padding: 1rem 1rem 0.75rem 1rem;

    &.isIOS {
      padding: 9px 1rem 11px 1rem;
      .title {
        font-size: 17px;
        font-weight: 700;
        line-height: 1.38rem;
      }
    }
  }

  &.hasImage {
    padding-top: 1rem;
  }
`;

const ContextWrapper = styled.div`
  position: relative;
  width: ${sizes.full};
`;

const Image = styled.img`
  width: 100%;
  object-fit: cover;
  margin-bottom: 1rem;

  &.isMobile {
    margin-bottom: 0.5rem;
  }
`;

const ChildrenWrapper = styled.div`
  overflow-y: hidden;
  color: ${colors.text060};
  font-weight: 400;
  font-size: 14px;
  line-height: 22px;
  padding: 0 2rem 1.5rem ;

  &.is-single-string {
    white-space: pre-wrap;
  }

  &.isMobile {
    padding: 0 1rem;
  }

  &.isIOS {
    font-size: 13px;
    line-height: 18px;
    text-align: center;
    letter-spacing: -0.078px;
  }
`;

const ButtonWrapper = styled.div`
  display: flex;
  flex-direction: row-reverse;
  background-color: ${colors.white};
  border-top: 1px solid rgba(0, 0, 0, 0.08);
  padding: 1.5rem 2rem;
  position: sticky;
  bottom: 0;

  button{
    margin-left: 4px;
    text-transform: uppercase;
  }

  .buttonAction2, .buttonAction3 {
    color: ${colors.text};
  }

  &.isMobileVertical {
    flex-wrap: wrap;
    align-items: center;
    flex-direction: column;
    padding: 0 1rem;

    button {
      width: 100%;
      margin-left: 0;
      margin-top: 0.75rem;
      text-align: center;
      justify-content: center;
    }
  }

  &.isMobile {
    padding: 1rem;
    width: 100%;

    &:not(.hasScrollbar) {
      position: fixed;
    }
  }

  &.isIOS {
    padding: 0.5rem;
    button{
      text-transform: capitalize;
    }
  }
`;

export {
  Modal,
  Backdrop,
  StyledPopup,
  StyledHeader,
  ContextWrapper,
  Image,
  ChildrenWrapper,
  ButtonWrapper,
};
