import React from 'react';
import theme from '../../theme';

import { cx, Icon, noop } from '../../index';

import {
  StepperContainer,
  IconWrapper,
  LabelValue,
} from './styles';

const { colors } = theme;
/**
 * Renders a stepper element.
 */

export type StepperProps = {
  /**
   * Stepper id
   */
  id?: string,
  /**
   * Stepper value
   */
  value?: number | string,
  /**
   * Stepper className
   */
  className?: string,
  /**
   * Change stepper active state color
   */
  color?: string,
  /**
   * Whether this stepper is disabled initially or not
   */
  disabled?: boolean,
  /**
   * Whether this stepper is disabled Decrease initially or not
   */
  isDisableDecrease?: boolean,
  /**
   * Whether this stepper is disabled Increase initially or not
   */
  isDisableIncrease?: boolean,
  /**
   * Change event
   */
  onChange?: (value: number) => void,
};

export const Stepper = (
  {
    value = 0,
    color = 'secondary',
    disabled = false,
    isDisableDecrease = false,
    isDisableIncrease = false,
    onChange = noop,
    ...props
  }: StepperProps) => {
  const inputAttrs = {
    disabled,
    ...props,
  };
  const colorStepper = colors?.[color] || color || colors.secondary;

  const handleDecrease = () => {
    onChange(Number(value) - 1);
  };

  const handleIncrease = () => {
    onChange(Number(value) + 1);
  };

  return (
    <StepperContainer>
      <IconWrapper
        onClick={handleDecrease}
        colorStepper={colorStepper}
        className={cx((disabled || isDisableDecrease) && 'disabled')}
      >
        <Icon name="minus-circle-outline" />
      </IconWrapper>
      <LabelValue {...inputAttrs}>{value}</LabelValue>
      <IconWrapper
        onClick={handleIncrease}
        colorStepper={colorStepper}
        className={cx((disabled || isDisableIncrease) && 'disabled')}
      >
        <Icon name="add-circle-outline" />
      </IconWrapper>
    </StepperContainer>
  );
};
