import React from 'react';
import styled from 'styled-components';
import { Button } from '../../index';
import { Icon } from '../../Icon'

const Grid = styled.div`
  display: flex;
  flex-wrap: wrap;
`;

const Col = styled.div`
  min-width: 12rem;
  margin: 1rem;
  display: inline-block;
`;

const buttonStories = {
  title: 'Components/Button',
  component: Button,
  parameters: {
    docs: {
      description: {
        component: `Text Button component.
        \`🧪 Beta\` [\`🎨 Figma Specs\`](https://www.figma.com/file/GKZuT2KxQpY4rty2hhGLE3/Mudah-Design-System?node-id=149%3A10)`,
      },
    },
  },
  argTypes: {
    styles: {
      defaultValue: 'btn-pri-hi',
    },
    disabled: {
      defaultValue: false,
    },
  },
};

export default buttonStories;

export const Overview = (args: any) => {
  const handleClick = () => console.log('on Click');
  return (
    <>
      <Button {...args} onClick={handleClick}>
        BUTTON
      </Button>
    </>
  );
};

export const ColorAndIcon = () => {
  const handleClick = () => console.log('on Click');
  return (
    <div>
      <Grid>
        <Col>
          <Button styles="btn-pri-hi" onClick={handleClick}>
            PRIMARY
          </Button>
        </Col>
        <Col>
          <Button styles="btn-sec-hi" onClick={handleClick}>
            SECONDARY
          </Button>
        </Col>
        <Col>
          <Button styles="btn-net-hi" onClick={handleClick}>
            NEUTRAL
          </Button>
        </Col>
      </Grid>
      <Grid>
        <Col>
          <Button styles="btn-pri-hi" onClick={handleClick}>
            <Icon name="search" />
            PRIMARY
          </Button>
        </Col>
        <Col>
          <Button styles="btn-sec-hi" onClick={handleClick}>
            <Icon name="search" />
            SECONDARY
          </Button>
        </Col>
        <Col>
          <Button styles="btn-net-hi" onClick={handleClick}>
            <Icon name="search" />
            NEUTRAL
          </Button>
        </Col>
      </Grid>
    </div>
  );
};

ColorAndIcon.parameters = {
  docs: {
    description: {
      story: '`Color And Icon`',
    },
  },
};

export const VariantOutline = () => {
  const handleClick = () => console.log('on Click');
  return (
    <Grid>
      <Col>
        <Button styles="btn-pri-med" onClick={handleClick}>
          BUTTON
        </Button>
      </Col>
      <Col>
        <Button styles="btn-sec-med" onClick={handleClick}>
          BUTTON
        </Button>
      </Col>
      <Col>
        <Button styles="btn-net-med" onClick={handleClick}>
          BUTTON
        </Button>
      </Col>
    </Grid>
  );
};

VariantOutline.parameters = {
  docs: {
    description: {
      story: '`Button Outline`',
    },
  },
};

export const VariantText = () => {
  const handleClick = () => console.log('on Click');
  return (
    <Grid>
      <Col>
        <Button styles="btn-pri-low" onClick={handleClick}>
          BUTTON
        </Button>
      </Col>
      <Col>
        <Button styles="btn-sec-low" onClick={handleClick}>
          BUTTON
        </Button>
      </Col>
      <Col>
        <Button styles="btn-net-low" onClick={handleClick}>
          BUTTON
        </Button>
      </Col>
    </Grid>
  );
};

VariantText.parameters = {
  docs: {
    description: {
      story: '`Button text`',
    },
  },
};

export const VariantHyperlink = () => {
  const handleClick = () => console.log('on Click');
  return (
    <Grid>
      <Col>
        <Button styles="hyperlink" onClick={handleClick}>
          hyperlink
        </Button>
      </Col>
    </Grid>
  );
};

VariantHyperlink.parameters = {
  docs: {
    description: {
      story: '`hyperlink`',
    },
  },
};
export const Disabled = () => {
  const handleClick = () => console.log('on Click');
  return (
    <Grid>
      <Grid>
        <Col>
          <Button disabled styles="btn-pri-hi" onClick={handleClick}>
            BUTTON
          </Button>
        </Col>
        <Col>
          <Button disabled styles="btn-sec-hi" onClick={handleClick}>
            BUTTON
          </Button>
        </Col>
        <Col>
          <Button disabled styles="btn-net-hi" onClick={handleClick}>
            BUTTON
          </Button>
        </Col>
      </Grid>
      <Grid>
        <Col>
          <Button disabled styles="btn-pri-med" onClick={handleClick}>
            BUTTON
          </Button>
        </Col>
        <Col>
          <Button disabled styles="btn-sec-med" onClick={handleClick}>
            BUTTON
          </Button>
        </Col>
        <Col>
          <Button disabled styles="btn-net-med" onClick={handleClick}>
            BUTTON
          </Button>
        </Col>
      </Grid>
      <Grid>
        <Col>
          <Button disabled styles="btn-pri-low" onClick={handleClick}>
            BUTTON
          </Button>
        </Col>
        <Col>
          <Button disabled styles="btn-sec-low" onClick={handleClick}>
            BUTTON
          </Button>
        </Col>
        <Col>
          <Button disabled styles="btn-net-low" onClick={handleClick}>
            BUTTON
          </Button>
        </Col>
        <Col>
          <Button disabled styles="hyperlink" onClick={handleClick}>
            hyperlink
          </Button>
        </Col>
      </Grid>
    </Grid>
  );
};

Disabled.parameters = {
  docs: {
    description: {
      story: '`Disabled`',
    },
  },
};
