import React, { useState } from 'react';
import styled from 'styled-components';

import { Checkbox } from '../../index';

const Grid = styled.div`
  display: grid;
  grid-template-columns: 1fr;
  grid-template-rows: auto auto auto auto;
`;

const Col = styled.div`
  margin-bottom: 2rem;
  margin-right: 2rem;
  display: inline-block;
`;

const checkboxStories = {
  title: 'Components/Checkbox',
  component: Checkbox,
  parameters: {
    docs: {
      description: {
        component: `Mudah UI Checkbox Component

\`🧪 Beta\` [\`🎨 Figma Specs\`](https://www.figma.com/file/GKZuT2KxQpY4rty2hhGLE3/Mudah-Design-System?node-id=271%3A7583)
`,
      },
    },
  },
  argTypes: {
    id: { control: null },
    label: { defaultValue: 'Label' },
    description: { defaultValue: 'Far far away, behind the word mountains, far from the countries.' },
    disabled: {},
    color: {},
    type: { control: null },
    className: { control: null },
    name: { control: null },
  },
};

export default checkboxStories;

export const Overview = (args) => {
  const [checked, setChecked] = useState(false);
  const onCheckboxChanged = (event) => setChecked(event.target.checked);

  return (
    <Checkbox
      {...args}
      checked={checked}
      onChange={onCheckboxChanged}
    />
  );
};

export const WithLabel = () => {
  const [checked, setChecked] = useState(false);
  const onCheckboxChanged = (event) => setChecked(event.target.checked);

  return (
    <Grid>
      <Col>
        <Checkbox
          type="checkbox"
          label="Checkbox"
          description="Far far away, behind the word mountains, far from the countries."
          checked={checked}
          onChange={onCheckboxChanged}
        />
      </Col>
      <Col>
        <Checkbox
          type="radio"
          label="Radio"
          description="Far far away, behind the word mountains, far from the countries."
          checked={checked}
          onChange={onCheckboxChanged}
        />
      </Col>
      <Col>
        <Checkbox
          type="switch"
          label="Switch"
          description="Far far away, behind the word mountains, far from the countries."
          checked={checked}
          onChange={onCheckboxChanged}
        />
      </Col>
    </Grid>
  );
};

WithLabel.parameters = {
  docs: {
    description: {
      story: '`type = checkbox | raido | switch`',
    },
  },
};

export const WithoutLabel = () => {
  const [checked, setChecked] = useState(false);
  const onCheckboxChanged = (event) => setChecked(event.target.checked);

  return (
    <div>
      <Col>
        <Checkbox
          type="checkbox"
          checked={checked}
          onChange={onCheckboxChanged}
        />
      </Col>
      <Col>
        <Checkbox
          type="radio"
          checked={checked}
          onChange={onCheckboxChanged}
        />
      </Col>
      <Col>
        <Checkbox
          type="switch"
          checked={checked}
          onChange={onCheckboxChanged}
        />
      </Col>
    </div>
  );
};

WithoutLabel.parameters = {
  docs: {
    description: {
      story: '',
    },
  },
};

export const Disabled = () => {
  const [checked, setChecked] = useState(false);
  const onCheckboxChanged = (event) => setChecked(event.target.checked);

  return (
    <Grid >
      <Col>
        <Checkbox
          type="checkbox"
          label="Checkbox"
          description="Far far away, behind the word mountains, far from the countries."
          checked={checked}
          onChange={onCheckboxChanged}
          disabled
        />
      </Col>
      <Col>
        <Col>
          <Checkbox
            type="checkbox"
            checked={checked}
            onChange={onCheckboxChanged}
            disabled
          />
          <Checkbox
            type="checkbox"
            checked={!checked}
            onChange={onCheckboxChanged}
            disabled
          />
        </Col>
        <Col>
          <Checkbox
            type="radio"
            checked={checked}
            onChange={onCheckboxChanged}
            disabled
          />
          <Checkbox
            type="radio"
            checked={!checked}
            onChange={onCheckboxChanged}
            disabled
          />
        </Col>
        <Col>
          <Checkbox
            type="switch"
            checked={checked}
            onChange={onCheckboxChanged}
            disabled
          />
          <Checkbox
            type="switch"
            checked={!checked}
            onChange={onCheckboxChanged}
            disabled
          />
        </Col>
      </Col>
    </Grid>
  );
};

Disabled.parameters = {
  docs: {
    description: {
      story: '',
    },
  },
};
