import React, { useState } from 'react';
import styled  from 'styled-components';

import { Chip, Icon } from '../../index';

const chipStories = {
  title: 'Components/Chip',
  component: Chip,
  parameters: {
    docs: {
      description: {
        component: `Mudah UI Chip Component

\`🧪 Beta\` [\`🎨 Figma Specs\`](https://www.figma.com/file/GKZuT2KxQpY4rty2hhGLE3/Mudah-Design-System?node-id=2094%3A25882)
`,
      },
    },
  },
  argTypes: {
    id: { control: null },
    label: { defaultValue: 'Action Chip' },
    value: { defaultValue: false },
    disabled: { defaultValue: false },
    color: {},
    className: { control: null },
    name: { control: null },
  },
};

export default chipStories;

export const Overview = (args) => {
  const [value, setValue] = useState(args.value);
  const onChipChanged = (event) => setValue(event);

  return (
    <Chip
      {...args}
      value={value}
      onChange={onChipChanged}
    />
  );
};

export const PrefixIcon = () => {
  const [value, setValue] = useState(false);
  const onChipChanged = (event) => setValue(event);

  return (
    <Chip
      value={value}
      label="Action Chip"
      onChange={onChipChanged}
      prefixIcon="add-circle-outline"
    />
  );
};

export const SuffixIcon = () => {
  const [value, setValue] = useState(false);
  const onChipChanged = (event) => setValue(event);

  return (
    <Chip
      value={value}
      label="Action Chip"
      onChange={onChipChanged}
      suffixIcon="close"
    />
  );
};

export const Disabled = () => {
  const [value, setValue] = useState(false);
  const onChipChanged = (event) => setValue(event);

  return (
    <Chip
      disabled
      value={value}
      label="Disabled"
      onChange={onChipChanged}
      suffixIcon="close"
    />
  );
};

export const Variants = () => {

  const [chipValues, setChipValues] = useState([
    {
      name: 'Primary',
      value: true,
      disable: false,
    },
    {
      name: 'Secondary',
      value: true,
      disable: false,
      color: 'secondary',
    },
    {
      name: 'Yellow',
      value: true,
      disable: false,
      color: 'yellow',
    },
    {
      name: '#ff7802 color',
      value: true,
      disable: false,
      color: '#ff7802',
      suffixIcon: "add-circle-outline",
    },
    {
      name: 'Disabled',
      value: false,
      disable: true,
    },
  ]);

  const onChipChanged = (value, item) => {
    const updateChipValues = [...chipValues];
    const index = chipValues.findIndex(o => o.name === item.name);
    updateChipValues[index] = { ...item, value };
    setChipValues(updateChipValues);
  };

  const ChipWrapper = styled.div`
    margin: 0.5rem;
    display: inline-block;
  `;

  return (
    <>
      {chipValues.map(item => (
        <ChipWrapper>
          <Chip
            color={item.color}
            value={item.value}
            disabled={item.disable}
            label={item.name}
            onChange={(e) => onChipChanged(e, item)}
            prefixIcon="add-circle-outline"
            suffixIcon={item.suffixIcon || <Icon name="close" />}
          />
        </ChipWrapper>
      ))}
    </>
  );
};
