import React from 'react';
import styled from 'styled-components';

import { Infobox } from '../../index';

const Layout = styled.div`
  max-width: 47.5rem;
  display: grid;
  grid-gap: 20px;
`;

const stepperStories = {
  title: 'Components/Infobox',
  component: Infobox,
  parameters: {
    docs: {
      description: {
        component: `Mudah UI Infobox Component

\`🧪 Beta\` [\`🎨 Figma Specs\`](https://www.figma.com/file/GKZuT2KxQpY4rty2hhGLE3/Mudah-Design-System?node-id=271%3A7583)
`,
      },
    },
  },
  argTypes: {
    title: { defaultValue: 'Subtitle Lorem Ipsum' },
    description: { defaultValue: 'Description Lorem ipsum dolor sit amet, consectetur adipiscing elit. Faucibus nisl, euismod malesuada vivamus lobortis scelerisque pellentesque amet.' },
    icon: { defaultValue: "alert-circle" },
    isButton: { defaultValue: true },
    buttonLabel: { defaultValue: 'cta' },
    isHighEmphasis: { defaultValue: true },
    color: {},
    className: { control: null },
  },
};
export default stepperStories;

export const Overview = (args) => {
  const handleOnClick = () => alert('click');

  return (
    <Layout>
      <Infobox
        {...args}
        onClick={handleOnClick}
      />
    </Layout>
  );
};

export const TitleAndButton = () => {
  return (
    <Layout>
      <Infobox
        title="Subtitle Lorem Ipsum"
        description="Description Lorem ipsum dolor sit amet, consectetur adipiscing elit. Faucibus nisl, euismod malesuada vivamus lobortis scelerisque pellentesque amet."
        isButton
      />
    </Layout>
  );
};
export const TitleAndIcon = () => {
  return (
    <Layout>
      <Infobox
        title="Subtitle Lorem Ipsum"
        description="Description Lorem ipsum dolor sit amet, consectetur adipiscing elit. Faucibus nisl, euismod malesuada vivamus lobortis scelerisque pellentesque amet."
        isButton={false}
        icon="alert-circle"
      />
    </Layout>
  );
};

export const DesciptionOnly = () => {
  return (
    <Layout>
      <Infobox
        description="Description Lorem ipsum dolor sit amet, consectetur adipiscing elit. Faucibus nisl, euismod malesuada vivamus lobortis scelerisque pellentesque amet."
        isButton={false}
      />
    </Layout>
  );
};

export const TitleAndDesciption = () => {
  return (
    <Layout>
      <Infobox
        title="Subtitle Lorem Ipsum"
        description="Description Lorem ipsum dolor sit amet, consectetur adipiscing elit. Faucibus nisl, euismod malesuada vivamus lobortis scelerisque pellentesque amet."
        isButton={false}
      />
    </Layout>
  );
};

export const TitleOnly = () => {
  return (
    <Layout>
      <Infobox
        title="Subtitle Lorem Ipsum"
      />
    </Layout>
  );
};

export const IconOnly = () => {
  return (
    <Layout>
      <Infobox
        icon="alert-circle"
      />
    </Layout>
  );
};

export const IconAndTitle = () => {
  return (
    <Layout>
      <Infobox
        icon="alert-circle"
        title="Subtitle Lorem Ipsum"
      />
    </Layout>
  );
};

export const HighEmphasis = () => {
  return (
    <Layout>
      <Infobox
        title="Subtitle Lorem Ipsum"
        description="Description Lorem ipsum dolor sit amet, consectetur adipiscing elit. Faucibus nisl, euismod malesuada vivamus lobortis scelerisque pellentesque amet."
        isButton
        icon="alert-circle"
        isHighEmphasis
      />
    </Layout>
  );
};

export const Colors = () => {
  return (
    <Layout>
      <Infobox
        title="Subtitle Lorem Ipsum"
        description="Description Lorem ipsum dolor sit amet, consectetur adipiscing elit. Faucibus nisl, euismod malesuada vivamus lobortis scelerisque pellentesque amet."
        isButton
        icon="alert-circle"
        isHighEmphasis
        color="green"
      />
      <Infobox
        title="Subtitle Lorem Ipsum"
        description="Description Lorem ipsum dolor sit amet, consectetur adipiscing elit. Faucibus nisl, euismod malesuada vivamus lobortis scelerisque pellentesque amet."
        isButton
        icon="alert-circle"
        isHighEmphasis
        color="red"
      />
      <Infobox
        title="Subtitle Lorem Ipsum"
        description="Description Lorem ipsum dolor sit amet, consectetur adipiscing elit. Faucibus nisl, euismod malesuada vivamus lobortis scelerisque pellentesque amet."
        isButton
        icon="alert-circle"
        isHighEmphasis
        color="neutral"
      />
    </Layout>
  );
};

