import React, { useState} from 'react';
import styled from 'styled-components';

import { Input } from '../../index';

const WrapperInput = styled.div`
  max-width: 25rem;
`;

const inputStories = {
  title: 'Components/Input',
  component: Input,
  parameters: {
    docs: {
      description: {
        component: `Text Input component.

\`🧪 Beta\` [\`🎨 Figma Specs\`](https://www.figma.com/file/GKZuT2KxQpY4rty2hhGLE3/Mudah-Design-System?node-id=160%3A5803)
`,
      },
    },
  },
  argTypes: {
    label: {
      defaultValue: 'Text Field Title',
    },
    assitiveText: {
      defaultValue: 'Please enter whole amount',
    },
    prefix: {},
    suffix: {},
    disabled: {},
    required: {},
    status: {},
    id: { control: null },
    name: { control: null },
    value: { control: null },
    onBlur: { control: null },
    onFocus: { control: null },
    inputRef: { control: null },
    characterLimit: {
      control: {
        type: 'number',
        min: 0,
      },
    },
  },
};

export default inputStories;

// top-most story will have the props breakdown
export const Overview = (args) => {
  const [value, setValue] = useState('');
  return (
    <WrapperInput>
      <Input {...args} value={value} onChange={(e) => setValue(e.currentTarget.value)} />
    </WrapperInput>
  );
};

export const ValueBinding = () => {
  const [value, setValue] = useState('');
  return (
    <WrapperInput>
      <Input label="Label cum placeholder..." value={value} onChange={(e) => setValue(e.currentTarget.value)} />
    </WrapperInput>
  );
};

ValueBinding.parameters = {
  docs: {
    description: {
      story: 'Currently, Input only support controlled HTML &lt;input /&gt;',
    },
  },
};

export const WithAssitiveText = () => {
  const [value, setValue] = useState('');
  return (
    <WrapperInput>
      <Input
        label="Label cum placeholder..."
        value={value}
        onChange={(e) => setValue(e.currentTarget.value)}
        assitiveText="Assitive Text"
      />
    </WrapperInput>
  );
};

WithAssitiveText.parameters = {
  docs: {
    description: {
      story: '`assitiveText` is the small caption below the input box',
    },
  },
};

export const WithIcon = () => {
  const [value, setValue] = useState('');
  return (
    <WrapperInput>
      <Input
        label="Icon input"
        value={value}
        icon="info"
        onChange={(e) => setValue(e.currentTarget.value)}
      />
    </WrapperInput>
  );
};

WithIcon.parameters = {
  docs: {
    description: {
      story:
        '`icon` will let Input display a Icon, support type HTML element &lt;Icon /&gt;`',
    },
  },
};

export const Required = () => {
  const [value, setValue] = useState('');
  return (
    <WrapperInput>
      <Input
        label="Required input"
        required
        onChange={(e) => setValue(e.currentTarget.value)}
        value={value}
      />
    </WrapperInput>
  );
};

Required.parameters = {
  docs: {
    description: {
      story:
        'Enable `required` will let Input display a red * on the label but validation is not forced for now',
    },
  },
};

export const WithCharacterLimit = () => {
  const [value, setValue] = useState('');
  return (
    <WrapperInput>
      <Input
        label="Character Limit input"
        onChange={(e) => setValue(e.currentTarget.value)}
        value={value}
        characterLimit={10}
        placeholder="Placeholder....."
      />
    </WrapperInput>
  );
};

WithCharacterLimit.parameters = {
  docs: {
    description: {
      story: 'Use `characterLimit` to limit number of character of Input',
    },
  },
};

export const ErrorStatus = () => {
  const [value, setValue] = useState('');
  const status = !value ? 'error' : 'default';
  return (
    <WrapperInput>
      <Input
        status={status}
        label="Error Status input"
        assitiveText="Error message here"
        value={value}
        onChange={(e) => setValue(e.currentTarget.value)}
      />
    </WrapperInput>
  );
};

ErrorStatus.parameters = {
  docs: {
    description: {
      story:
        'Set `status="error"` will let Input has red borders and assitive Text, indicate error status.',
    },
  },
};

export const Disabled = () => (
  <WrapperInput>
    <Input label="Read only" disabled />
  </WrapperInput>
);

Disabled.parameters = {
  docs: {
    description: {
      story:
        'Enable `disabled` will set attribute `disabled` to the HTML input. Effectively, Input is read-only.',
    },
  },
};


