import React, { useState, useEffect } from 'react';
import styled from 'styled-components';

import { Button, Input, Popup } from '../../index';

const popupStories = {
  title: 'Components/Popup',
  component: Popup,
  parameters: {
    docs: {
      description: {
        component: `Mudah UI Popup component.

\`🧪 Beta\` [\`🎨 Figma Specs\`](https://www.figma.com/file/GKZuT2KxQpY4rty2hhGLE3/Mudah-Design-System?node-id=1061%3A21813)
`,
      },
    },
  },
  argTypes: {
    title: {
      defaultValue: 'Popup title',
    },
    image: {},
    children: {
      defaultValue:
        'Body 2: Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam.',
      control: {
        type: 'text',
      },
    },
    open: {},
    className: { control: null },
    btnLabel1: {
      defaultValue: 'confirm',
    },
    btnLabel2: {
      defaultValue: 'cancel',
    },
    btnLabel3: {
      defaultValue: '',
    },
    isMobileVertical: {
      defaultValue: false,
    },
    isCloseButtonLeft: {
      defaultValue: false,
    },
  },
};

export default popupStories;

const onMainBtnClick = () => {
  alert('Button clicked.');
};

export const Overview = (args) => {
  const Wrapper = styled.div`
    margin-top: 1rem;
    max-width: 35rem;

    p {
      margin-bottom: 1rem;
     }
  `;

  const [open, setOpen] = useState(false);
  const [value, setValue] = useState('');
  const toggleModel = () => {
    setOpen(!open);
  };
  useEffect(() => {
    setOpen(args.open);
  }, [args.open]);

  return (
    <>
      <Button onClick={toggleModel}>Open Popup</Button>
      <Popup
        {...args}
        open={open}
        onClose={toggleModel}
        onButtonClick1={onMainBtnClick}
        onButtonClick2={() => setOpen(false)}
      >
        <Wrapper>
          <p>Body 2: Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam.</p>
          <p>Body 2: Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam.</p>
          <Input value={value} onChange={e => setValue(e.currentTarget.value)} label="Text Field Title" />
          <Input value={value} onChange={e => setValue(e.currentTarget.value)} label="Text Field Title" />
        </Wrapper>
      </Popup>
    </>
  );
};

export const WithImage = (args) => {
  const [open, setOpen] = useState(false);
  const toggleModel = () => {
    setOpen(!open);
  };
  useEffect(() => {
    setOpen(args.open);
  }, [args.open]);

  const Wrapper = styled.div`
    max-width: 35rem;
    .image {
      max-width: 37rem;
      height: 20rem;
    }
  `;

  return (
    <Wrapper>
      <Button onClick={toggleModel}>Open Popup</Button>
      <Popup
        {...args}
        open={open}
        maxWidth="37rem"
        onClose={toggleModel}
        onButtonClick1={onMainBtnClick}
        onButtonClick2={() => setOpen(false)}
        image="https://www.simplilearn.com/ice9/free_resources_article_thumb/what_is_image_Processing.jpg"
      >
        Body 2: Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam.
      </Popup>
    </Wrapper>
  );
};

export const Variants = (args) => {
  const [open, setOpen] = useState(false);
  const [value, setValue] = useState('');
  const toggleModel = () => {
    setOpen(!open);
  };
  useEffect(() => {
    setOpen(args.open);
  }, [args.open]);

  return (
    <>
      <Button onClick={toggleModel}>Open Popup</Button>
      <Popup
        {...args}
        open={open}
        maxWidth="37rem"
        onClose={toggleModel}
        isMobileVertical
        btnLabel1={<Button styles="btn-pri-hi" onClick={onMainBtnClick}>Action 1</Button>}
        btnLabel2={<Button styles="btn-sec-med" onClick={() => setOpen(false)}>Action 2</Button>}
        btnLabel3={<Button styles="btn-net-low" onClick={() => setOpen(false)}>Action 3</Button>}
        image="https://www.simplilearn.com/ice9/free_resources_article_thumb/what_is_image_Processing.jpg"
      >
        <div>
          <p>Lorem ipsum dolor sit amet</p>
          <ul>
            <li>Body 2: Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam.</li>
            <li>Body 2: Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam.</li>
            <li>Body 2: Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam.</li>
          </ul>
          <Input value={value} onChange={e => setValue(e.currentTarget.value)} label="Text Field Title" />
          <Input value={value} onChange={e => setValue(e.currentTarget.value)} label="Text Field Title" />
          <p>Body 2: Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam.</p>
        </div>
      </Popup>
    </>
  );
};
