import React, { useState } from 'react';
import { Stepper } from '../../index';

const stepperStories = {
  title: 'Components/Stepper',
  component: Stepper,
  parameters: {
    docs: {
      description: {
        component: `Mudah UI Stepper Component

\`🧪 Beta\` [\`🎨 Figma Specs\`](https://www.figma.com/file/GKZuT2KxQpY4rty2hhGLE3/Mudah-Design-System?node-id=271%3A7583)
`,
      },
    },
  },
  argTypes: {
    id: { control: null },
    value: { defaultValue: 7},
    disabled: {},
    color: {},
    type: { control: null },
    className: { control: null },
    name: { control: null },
  },
};

export default stepperStories;

export const Overview = (args) => {
  const [value, setValue] = useState(args.value);
  const onStepperChanged = (event) => setValue(event);

  return (
    <Stepper
      {...args}
      value={value}
      onChange={onStepperChanged}
    />
  );
};

export const DisableDecrease = () => {
  const [value, setValue] = useState(33);
  const onStepperChanged = (event) => setValue(event);

  return (
    <Stepper
      value={value}
      onChange={onStepperChanged}
      isDisableDecrease
    />
  );
};

DisableDecrease.parameters = {
  docs: {
    description: {
      story:
        'Enable `isDisableDecrease` will set attribute `isDisableDecrease` to the HTML input.',
    },
  },
};

export const DisableIncrease = () => {
  const [value, setValue] = useState(33);
  const onStepperChanged = (event) => setValue(event);

  return (
    <Stepper
      value={value}
      onChange={onStepperChanged}
      isDisableIncrease
    />
  );
};

DisableIncrease.parameters = {
  docs: {
    description: {
      story:
        'Enable `isDisableIncrease` will set attribute `isDisableIncrease` to the HTML ',
    },
  },
};

export const Disabled = () => (
  <Stepper value="33" disabled />
);

Disabled.parameters = {
  docs: {
    description: {
      story:
        'Enable `disabled` will set attribute `disabled` to the HTML input. Effectively, Stepper is read-only.',
    },
  },
};


