const path = require("path");

module.exports = {
  stories: ["../**/*.stories.tsx"],
  addons: [
    "@storybook/addon-essentials"
  ],
  webpackFinal: async (config) => {
    config.module.rules.push({
      test: /\.(ts|tsx)$/,
      loader: require.resolve("babel-loader"),
      options: {
        presets: [require.resolve("babel-preset-react-app")],
      },
    });

    // Modify storybook's file-loader rule to avoid conflicts with @svgr/webpack
    const fileLoaderRuleIndex = config.module.rules.findIndex((rule) =>
      rule.test.test(".svg")
    );
    config.module.rules[fileLoaderRuleIndex].exclude = /\.svg$/;

    config.module.rules.push({
      test: /\.svg$/,
      loaders: [
        {
          loader: "@svgr/webpack",
          options: {
            svgoConfig: {
              plugins: {
                removeViewBox: false,
              },
            },
          },
        },
      ],
    });

    config.resolve.modules = [
      ...(config.resolve.modules || []),
      path.resolve("./"),
    ];

    config.resolve.extensions.push(".ts", ".tsx");

    return config;
  },
};
